summaryrefslogtreecommitdiffstats
path: root/Source/cmCableCommand.h
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
committerBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
commitd0a8794746f6de026f1c69652cd09caf8be9cfab (patch)
tree2143ad59bf1fef6f340dd7fb199f556eadff0ef4 /Source/cmCableCommand.h
parente5e2a57bfbf1aac2c265e894db82d2b2d5673084 (diff)
downloadCMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.zip
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.gz
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.bz2
ENH: CABIL -> CABLE rename.
Diffstat (limited to 'Source/cmCableCommand.h')
-rw-r--r--Source/cmCableCommand.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/Source/cmCableCommand.h b/Source/cmCableCommand.h
index 211b70e..60e0ed9 100644
--- a/Source/cmCableCommand.h
+++ b/Source/cmCableCommand.h
@@ -13,42 +13,42 @@
See COPYRIGHT.txt for copyright details.
=========================================================================*/
-#ifndef cmCabilCommand_h
-#define cmCabilCommand_h
+#ifndef cmCableCommand_h
+#define cmCableCommand_h
#include "cmStandardIncludes.h"
#include "cmCommand.h"
#include "cmCabilData.h"
/** \class cmCabilCommand
* \brief Superclass for all cmCabil command classes.
*
* cmCabilCommand is the superclass for all CABIL-related commands.
* The C++ Automated Bindings for Interpreted Languages (CABIL,
* pronounced "sawbill") tool is configured using an XML input file.
* The input format is quite flexible, but XML is hard for humans to
* write by hand. The CABIL commands in CMake are designed to simplify
* the interface with only a small loss in functionality. These commands
* can be used to automatically generate CABIL configuration files.
*/
-class cmCabilCommand : public cmCommand
+class cmCableCommand : public cmCommand
{
public:
- cmCabilCommand();
- virtual ~cmCabilCommand();
+ cmCableCommand();
+ virtual ~cmCableCommand();
void WriteConfigurationHeader(std::ostream&) const;
void WriteConfigurationFooter(std::ostream&) const;
- cmTypeMacro(cmCabilCommand, cmCommand);
+ cmTypeMacro(cmCableCommand, cmCommand);
protected:
- void SetupCabilData();
+ void SetupCableData();
/**
* The cmCabilData holding common information for all cmCabilCommand
* instances.
*/
- cmCabilData* m_CabilData;
+ cmCableData* m_CableData;
};
@@ -13,42 +13,42 @@
#include "cmStandardIncludes.h"
#include "cmCommand.h"
-#include "cmCabilData.h"
+#include "cmCableData.h"
-/** \class cmCabilCommand
- * \brief Superclass for all cmCabil command classes.
+/** \class cmCableCommand
+ * \brief Superclass for all cmCable command classes.
*
@@ -13,42 +13,42 @@
*
- * cmCabilCommand is the superclass for all CABIL-related commands.
- * The C++ Automated Bindings for Interpreted Languages (CABIL,
- * pronounced "sawbill") tool is configured using an XML input file.
- * The input format is quite flexible, but XML is hard for humans to
- * write by hand. The CABIL commands in CMake are designed to simplify
- * the interface with only a small loss in functionality. These commands
- * can be used to automatically generate CABIL configuration files.
+ * cmCableCommand is the superclass for all CABLE-related commands.
+ * The C++ Automated Bindings for Language Extension (CABLE) tool is
+ * configured using an XML input file. The input format is quite
+ * flexible, but XML is hard for humans to write by hand. The CABLE
+ * commands in CMake are designed to simplify the interface with only
+ * a small loss in functionality. These commands can be used to
+ * automatically generate CABLE configuration files.
*/
@@ -13,42 +13,42 @@
/**
- * The cmCabilData holding common information for all cmCabilCommand
+ * The cmCableData holding common information for all cmCableCommand
* instances.
*/